==> maven-release-3.1.1-source-release.zip: maven-release-3.1.1/maven-release-api/src/main/java/org/apache/maven/shared/release/policy/version/VersionPolicy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.release.policy.version;

import org.apache.maven.shared.release.policy.PolicyException;
import org.apache.maven.shared.release.versions.VersionParseException;

/**
 * API for next version calculations, used by maven-release-plugin to suggest release and next development versions.
 *
 * @since 2.5.1 (MRELEASE-431)
 */
public interface VersionPolicy {
    /**
     * <p>getReleaseVersion.</p>
     *
     * @return the calculation of the release version from development state.
     * @param request the {@code VersionPolicyRequest}
     * @throws org.apache.maven.shared.release.policy.PolicyException if exception in the policy
     * @throws org.apache.maven.shared.release.versions.VersionParseException if exception parsing the version
     */
    VersionPolicyResult getReleaseVersion(VersionPolicyRequest request) throws PolicyException, VersionParseException;

    /**
     * <p>getDevelopmentVersion.</p>
     *
     * @return the calculation of the next development version from release state.
     * @param request the {@code VersionPolicyRequest}
     * @throws org.apache.maven.shared.release.policy.PolicyException if exception in the policy
     * @throws org.apache.maven.shared.release.versions.VersionParseException if exception parsing the version
     */
    VersionPolicyResult getDevelopmentVersion(VersionPolicyRequest request)
            throws PolicyException, VersionParseException;
}

==> maven-release-3.3.1-source-release.zip: maven-release-3.3.1/maven-release-api/src/main/java/org/apache/maven/shared/release/policy/version/VersionPolicy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.release.policy.version;

import org.apache.maven.shared.release.policy.PolicyException;
import org.apache.maven.shared.release.versions.VersionParseException;

/**
 * API for next version calculations, used by maven-release-plugin to suggest release and next development versions.
 *
 * @since 2.5.1 (MRELEASE-431)
 */
public interface VersionPolicy {
    /**
     * <p>getReleaseVersion.</p>
     *
     * @param request the {@code VersionPolicyRequest}
     * @return the release version derived from the development state
     * @throws org.apache.maven.shared.release.policy.PolicyException if exception in the policy
     * @throws org.apache.maven.shared.release.versions.VersionParseException if exception parsing the version
     */
    VersionPolicyResult getReleaseVersion(VersionPolicyRequest request) throws PolicyException, VersionParseException;

    /**
     * <p>getDevelopmentVersion.</p>
     *
     * @param request the {@code VersionPolicyRequest}
     * @return the next development version derived from release state
     * @throws org.apache.maven.shared.release.policy.PolicyException if exception in the policy
     * @throws org.apache.maven.shared.release.versions.VersionParseException if exception parsing the version
     */
    VersionPolicyResult getDevelopmentVersion(VersionPolicyRequest request)
            throws PolicyException, VersionParseException;
}
